@@ -19,6 +19,7 @@ using System.IO;
 public class IconView : Gtk.Layout {
 
 	// Public properties.
+	FSpot.PixbufCache cache;
 
 	/* Width of the thumbnails. */
 	protected int thumbnail_width = 128;
@@ -94,9 +95,6 @@ public class IconView : Gtk.Layout {
 	// Vertical spacing between the thumbnail and the row of tag icons.
 	protected const int TAG_ICON_VSPACING = 3;
 
-	// The loader.
-	private PixbufLoader pixbuf_loader;
-
 	// Various other layout values.
 	protected int cells_per_row;
 	protected int cell_width;
@@ -144,12 +142,12 @@ public class IconView : Gtk.Layout {
 
 
 	// Public API.
+	public IconView (IntPtr raw) : base (raw) {}
 
 	public IconView () : base (null, null)
 	{
-		pixbuf_loader = new PixbufLoader ();
-		pixbuf_loader.OnPixbufLoaded += HandlePixbufLoaded;
-
+		cache = new FSpot.PixbufCache ();
+		cache.OnPixbufLoaded += HandlePixbufLoaded;
 		selected_cells = new Hashtable ();
 
 		ScrollAdjustmentsSet += new ScrollAdjustmentsSetHandler (HandleScrollAdjustmentsSet);
@@ -223,10 +221,8 @@ public class IconView : Gtk.Layout {
 	public void UpdateThumbnail (int thumbnail_num)
 	{
 		FSpot.IBrowsableItem photo = collection.Items [thumbnail_num];
-		string thumbnail_path = Thumbnail.PathForUri (photo.DefaultVersionUri.ToString (), ThumbnailSize.Large);
-
-		//Console.WriteLine ("remove {0}", thumbnail_path);
-		ThumbnailCache.Default.RemoveThumbnailForPath (thumbnail_path);
+		string thumbnail_path = FSpot.ThumbnailGenerator.ThumbnailPath (photo.DefaultVersionUri);
+		cache.Remove (thumbnail_path);
 		InvalidateCell (thumbnail_num);
 	}
 
@@ -454,14 +450,14 @@ public class IconView : Gtk.Layout {
 		string thumbnail_path = Thumbnail.PathForUri (photo.DefaultVersionUri.ToString (), 
 							      ThumbnailSize.Large);
 
-		Pixbuf thumbnail = ThumbnailCache.Default.GetThumbnailForPath (thumbnail_path);			
-		if (thumbnail == null) {
-			// FIXME instead of making a request to load at a particular size here we
-			// request to load at the the full size because Gdk.Pixbuf loses the Option
-			// data when you load at a different size (I hate that).  See HandlePixbufLoaded
-			// for where we do the scaling to correct for this problem.
-			pixbuf_loader.Request (thumbnail_path, thumbnail_num);
-		}
+		
+		
+		FSpot.PixbufCache.CacheEntry entry = cache.Lookup (thumbnail_path);
+		if (entry == null)
+			cache.Request (thumbnail_path, thumbnail_num, ThumbnailWidth, ThumbnailHeight);
+		else
+			entry.Data = thumbnail_num;
+
 			
 		Gdk.GC gc = new Gdk.GC (BinWindow);
 		gc.Copy (Style.ForegroundGC (StateType.Normal));
@@ -490,6 +486,10 @@ public class IconView : Gtk.Layout {
 		Gdk.Rectangle image_bounds = Expand (bounds, - CELL_BORDER_WIDTH);
 		int expansion = ThrobExpansion (thumbnail_num, selected);
 
+		Gdk.Pixbuf thumbnail = null;
+		if (entry != null)
+			thumbnail = entry.ShallowCopyPixbuf ();
+
 		if (Expand (image_bounds, expansion + 1).Intersect (area, out image_bounds) && thumbnail != null) {
 			
 			PixbufUtils.Fit (thumbnail, ThumbnailWidth, ThumbnailHeight, 
@@ -498,26 +498,29 @@ public class IconView : Gtk.Layout {
 			region.X = (int) (bounds.X + (bounds.Width - region.Width) / 2);
 			region.Y = (int) bounds.Y + ThumbnailHeight - region.Height + CELL_BORDER_WIDTH;
 			
-
-			if (region.Width != thumbnail.Width || region.Height != thumbnail.Height)
-				pixbuf_loader.Request (thumbnail_path, thumbnail_num);
+			if (region.Width != thumbnail.Width && region.Height != thumbnail.Height)
+				cache.Reload (entry, thumbnail_num, thumbnail.Width, thumbnail.Height);
 
 			region = Expand (region, expansion);
 			Pixbuf temp_thumbnail;			
 
 			if (region.Width != thumbnail.Width && region.Height != thumbnail.Height) {
-				if (region.Width < thumbnail.Width && region.Height < thumbnail.Height)
+				if (region.Width < thumbnail.Width && region.Height < thumbnail.Height) {
 					temp_thumbnail = PixbufUtils.ScaleDown (thumbnail, 
 										region.Width, region.Height);
-				else
+					
+					if (entry.Reload && expansion == 0)
+						cache.Update (entry, PixbufUtils.ShallowCopy (thumbnail));
+
+				} else {
 					temp_thumbnail = thumbnail.ScaleSimple (region.Width, region.Height, 
 										InterpType.Bilinear);
+				}
 				
 				PixbufUtils.CopyThumbnailOptions (thumbnail, temp_thumbnail);
 			} else
 				temp_thumbnail = thumbnail;
 
-			
 			// FIXME There seems to be a rounding issue between the
 			// scaled thumbnail sizes, we avoid this for now by using
 			// the actual thumnail sizes here.
@@ -643,6 +646,35 @@ public class IconView : Gtk.Layout {
 					 cells_per_row - start_cell_column);
 
 		int i, cell_num;
+
+		FSpot.IBrowsableItem photo;
+		FSpot.PixbufCache.CacheEntry entry;
+		string thumbnail_path;
+
+		
+		// Preload the cache with images aroud the expose area
+		// FIXME the preload need to be tuned to the Cache size but this is a resonable start
+		
+		int len = (end_cell_row - start_cell_row + 20) * cells_per_row;
+		int scell = System.Math.Max ((start_cell_row - 10) * cells_per_row, 0);
+		int ecell = scell + len;
+		if (scell > collection.Items.Length - len) {
+		        ecell = collection.Items.Length;
+			scell = System.Math.Max (0, scell - len);
+		} else
+			ecell = scell + len;
+			
+		for (i = scell; i < ecell; i++) {
+			photo = collection.Items [i];
+			thumbnail_path = FSpot.ThumbnailGenerator.ThumbnailPath (photo.DefaultVersionUri);
+
+			entry = cache.Lookup (thumbnail_path);
+			if (entry == null)
+				cache.Request (thumbnail_path, i, ThumbnailWidth, ThumbnailHeight);
+				
+		}
+			
+
 		for (i = 0, cell_num = start_cell_num;
 		     i < num_rows && cell_num < collection.Items.Length;
 		     i ++) {
@@ -690,40 +722,59 @@ public class IconView : Gtk.Layout {
 		if (y_offset == adjustment.Value)
 			return false;
 
-		int num_thumbnails = collection.Items.Length;
-		int num_rows, start;
-
-		if (y_offset < adjustment.Value) {
-			int old_first_row = y_offset / cell_height;
-			int new_first_row = (int) (adjustment.Value / cell_height);
-
-			num_rows = new_first_row - old_first_row;
-			start = old_first_row * cells_per_row;
-		} else {
-			int old_last_row = (y_offset + Allocation.Height) / cell_height;
-			int new_last_row = ((int) adjustment.Value + Allocation.Height) / cell_height;
-
-			num_rows = old_last_row - new_last_row;
-			start = (new_last_row + 1) * cells_per_row;
-		}
-
-		for (int i = 0; i < cells_per_row * num_rows; i ++) {
-			if (start + i >= num_thumbnails)
-				break;
-
-			FSpot.IBrowsableItem photo = collection.Items [start + i];
-			string thumbnail_path = Thumbnail.PathForUri (photo.DefaultVersionUri.ToString (), ThumbnailSize.Large);
-			pixbuf_loader.Cancel (thumbnail_path);
-		}
-
 		y_offset = (int) adjustment.Value;
-
 		scroll_on_idle_id = 0;
 		return false;
 	}
 
 	private void Scroll ()
 	{
+		if (cells_per_row ==0)
+			return;
+
+		Gdk.Rectangle area = new Gdk.Rectangle ((int) Hadjustment.Value, 
+							(int) Vadjustment.Value,
+							Allocation.Width,
+							Allocation.Height);
+
+		int start_cell_column = Math.Max ((area.X - BORDER_SIZE) / cell_width, 0);
+		int start_cell_row = Math.Max ((area.Y - BORDER_SIZE) / cell_height, 0);
+		int start_cell_num = start_cell_column + start_cell_row * cells_per_row;
+
+		int start_cell_x, cell_y;
+		GetCellPosition (start_cell_num, out start_cell_x, out cell_y);
+
+		//int end_cell_column = Math.Max ((area.X + area.Width - BORDER_SIZE) / cell_width, 0);
+		int end_cell_row = Math.Max ((area.Y + area.Height - BORDER_SIZE) / cell_height, 0);
+
+		int i;
+
+		FSpot.IBrowsableItem photo;
+		FSpot.PixbufCache.CacheEntry entry;
+		string thumbnail_path;
+
+		// Preload the cache with images aroud the expose area
+		// FIXME the preload need to be tuned to the Cache size but this is a resonable start
+		
+		int len = (end_cell_row - start_cell_row + 10) * cells_per_row;
+		int scell = System.Math.Max ((start_cell_row - 5) * cells_per_row, 0);
+		int ecell = scell + len;
+		if (scell > collection.Items.Length - len) {
+		        ecell = collection.Items.Length;
+			scell = System.Math.Max (0, scell - len);
+		} else
+			ecell = scell + len;
+			
+		for (i = scell; i < ecell; i++) {
+			photo = collection.Items [i];
+			thumbnail_path = FSpot.ThumbnailGenerator.ThumbnailPath (photo.DefaultVersionUri);
+
+			entry = cache.Lookup (thumbnail_path);
+			if (entry == null)
+				cache.Request (thumbnail_path, i, ThumbnailWidth, ThumbnailHeight);
+				
+		}
+			
 		if (scroll_on_idle_id == 0)
 			scroll_on_idle_id = GLib.Idle.Add (new GLib.IdleHandler (HandleScrollOnIdle));
 	}
@@ -789,7 +840,7 @@ public class IconView : Gtk.Layout {
 		else if (y + cell_height > adjustment.Value + adjustment.PageSize)
 			adjustment.Value = y + cell_height - adjustment.PageSize;
 		
-#if USEIDLE
+#if true
 		Scroll ();
 #else
 		adjustment.Change ();
@@ -804,41 +855,39 @@ public class IconView : Gtk.Layout {
 		Scroll ();
 	}
 
-	private void HandlePixbufLoaded (PixbufLoader loader, string path, int order, Pixbuf result)
+	private void HandlePixbufLoaded (FSpot.PixbufCache cache, FSpot.PixbufCache.CacheEntry entry)
 	{
-		if (result == null) {
-			result = PixbufUtils.ErrorPixbuf;
-			//
-			// ThumbnailCache Takes Ownership and calls Dispose
-			// so we need to copy the ErrorPixbuf
-			//
-			result = new Pixbuf (result, 0, 0, result.Width, result.Height);
-		} 
+		Gdk.Pixbuf result = entry.ShallowCopyPixbuf ();
+		int order = (int) entry.Data;
 
 		if (order > 0 && order < collection.Items.Length) {
 			System.Uri uri = collection.Items [order].DefaultVersionUri;
+
+			if (result == null && !System.IO.File.Exists (FSpot.ThumbnailGenerator.ThumbnailPath (uri)))
+				FSpot.ThumbnailGenerator.Default.Request (uri.LocalPath, 0, 256, 256);
 			
-			if (!FSpot.PhotoLoader.ThumbnailIsValid (collection.Items [order].DefaultVersionUri, result)) {
-				System.Console.WriteLine ("regnerating thumbnail");
+			if (result == null)
+				return;
+			
+			if (!FSpot.PhotoLoader.ThumbnailIsValid (uri, result))
 				FSpot.ThumbnailGenerator.Default.Request (uri.LocalPath, 0, 256, 256);
-			}
 		}
-		       
+			
+		if (result == null)
+			return;
 
 		// We have to do the scaling here rather than on load because we need to preserve the 
 		// Pixbuf option iformation to verify the thumbnail validity later
 		int width, height;
-		PixbufUtils.Fit (result, ThumbnailWidth, ThumbnailHeight, true, out width, out height);
-
-
+		PixbufUtils.Fit (result, ThumbnailWidth, ThumbnailHeight, false, out width, out height);
 		if (result.Width != width && result.Height != height) {
-			Gdk.Pixbuf temp = PixbufUtils.ScaleToMaxSize (result, ThumbnailWidth, ThumbnailHeight);
-			PixbufUtils.CopyThumbnailOptions (result, temp);
+			//  System.Console.WriteLine ("scaling");
+			Gdk.Pixbuf temp = PixbufUtils.ScaleDown (result, width, height);
 			result.Dispose ();
 			result = temp;
 		}
 
-		ThumbnailCache.Default.AddThumbnail (path, result);
+		cache.Update (entry, result);
 		InvalidateCell (order);
 	}
 	
