@@ -22,6 +22,9 @@ public class SlideView : Gtk.Image {
 	uint flip_timer = 0;
 	uint transition_timer = 0;
 
+	bool animate = true;
+	uint animate_max = 110;
+
 	bool black = false;
 	uint flip_interval = 2000;
 	uint transition_interval = 75;
@@ -32,6 +35,15 @@ public class SlideView : Gtk.Image {
 		}
 	}
 
+	public bool Animate {
+		get {
+			return animate;
+		}
+		set {
+			animate = value;
+		}
+	}
+
 	public void Play () 
 	{
 		StopTweenIdle ();
@@ -121,7 +133,7 @@ public class SlideView : Gtk.Image {
 
 		prev.CopyArea (0, 0, width, height, current, 0, 0);
 		next.Composite (current, 0,0, width, height, 0, 0, 1, 1,
-				Gdk.InterpType.Nearest, (int)(255 * percent + 0.5));
+				Gdk.InterpType.Nearest, (int) System.Math.Round (255 * percent));
 		return current;
 	}
 
@@ -134,10 +146,10 @@ public class SlideView : Gtk.Image {
 
 		if (percent < 0.5)
 			prev.Composite (current, 0,0, width, height, 0, 0, 1, 1,
-					Gdk.InterpType.Nearest, (int)(255 * (1 - percent * 2) + 0.5));
+					Gdk.InterpType.Nearest, (int)System.Math.Round (255  * (1 - percent * 2)));
 		else
 			next.Composite (current, 0,0, width, height, 0, 0, 1, 1,
-					Gdk.InterpType.Nearest, (int)(255 * (percent * 2 - 1) + 0.5));
+					Gdk.InterpType.Nearest, (int)System.Math.Round (255 * (percent * 2 - 1)));
 		return current;
 	}
 
@@ -152,33 +164,9 @@ public class SlideView : Gtk.Image {
 
 	private Pixbuf GetScaled (Pixbuf orig)
 	{
-		int width = Allocation.Width;
-		int height = Allocation.Height;
-		Pixbuf scaled = new Pixbuf (Colorspace.Rgb, false, 8, width, height);
-		scaled.Fill (0);
-		
-		if (width < 10 || height < 10)
-			return scaled;	
-
-		if (orig == null) {
-			return scaled;
-		}
-
-		double scale = Math.Min (width / (double)orig.Width, height / (double)orig.Height);
-
-		int scale_width = (int)(scale * orig.Width);
-		int scale_height = (int)(scale * orig.Height);
-		int scale_x = (width - scale_width) / 2;
-		int scale_y = (height - scale_height) / 2;
-
-		orig.Composite (scaled, scale_x, scale_y, 
-				scale_width, scale_height,
-				scale_x, scale_y, scale, scale,
-				Gdk.InterpType.Bilinear,
-				255);
+		Pixbuf scaled = PixbufUtils.ScaleToAspect (orig, Allocation.Width, Allocation.Height);
 
 		orig.Dispose ();
-		System.GC.Collect ();
 		return scaled;
 	}
 
@@ -207,9 +195,15 @@ public class SlideView : Gtk.Image {
 		transition_timer = 0;
 		if (current_tween--  > 0) {
 			StartTransitionTimer ();
-
+			System.DateTime start_time = System.DateTime.Now;
 			this.FromPixbuf = tweens[current_tween];
 			GdkWindow.ProcessUpdates (false);
+			System.TimeSpan span = System.DateTime.Now  - start_time;
+			
+			if (animate && span.TotalMilliseconds > animate_max) {
+				animate = false;
+				System.Console.WriteLine ("Disabling slide animation due to excessive frame interval");
+			}
 		} else {
 			ShowNext ();
 
@@ -223,51 +217,57 @@ public class SlideView : Gtk.Image {
 	private bool HandleTweenIdle ()
 	{
 		using (Pixbuf prev = this.Pixbuf) {	
-		if (current_tween < tweens.Length && tweens[current_tween] == null) {
-			tweens[current_tween] = new Pixbuf (Colorspace.Rgb, false, 8, Allocation.Width, Allocation.Height);
-		}
-
-		switch (current_tween) {
-		case 9:
-			tweens[current_tween] = Blend (tweens[current_tween], prev, next, .15);
-			break;
-		case 8:
-			tweens[current_tween] = Blend (tweens[current_tween], prev, next, .3);
-			break;
-		case 7:
-			tweens[current_tween] = Blend (tweens[current_tween], prev, next, .4);
-			break;
-		case 6:
-			tweens[current_tween] = Blend (tweens[current_tween], prev, next, .5);
-			break;
-		case 5:
-			tweens[current_tween] = Blend (tweens[current_tween], prev, next, .6);
-			break;
-		case 4:
-			tweens[current_tween] = Blend (tweens[current_tween], prev, next, .7);
-			break;
-		case 3:
-			tweens[current_tween] = Blend (tweens[current_tween], prev, next, .8);
-			break;
-		case 2:
-			tweens[current_tween] = Blend (tweens[current_tween], prev, next, .9);
-			break;
-		case 1:
-			tweens[current_tween] = Blend (tweens[current_tween], prev, next, .97);
-			break;
-		case 0:
-			tweens[current_tween] = Blend (tweens[current_tween], prev, next, .99);
-			break;
-		default:
-			tween_idle = 0;
-			return false;
-		}
-
-		current_tween++;
-		return true;
+			if (!animate) {
+				ClearTweens ();
+				return false;
+			}
+			
+			if (current_tween < tweens.Length && tweens[current_tween] == null) {
+				tweens[current_tween] = new Pixbuf (Colorspace.Rgb, false, 8, 
+								    Allocation.Width, Allocation.Height);
+			}
+			
+			switch (current_tween) {
+			case 9:
+				tweens[current_tween] = Blend (tweens[current_tween], prev, next, .15);
+				break;
+			case 8:
+				tweens[current_tween] = Blend (tweens[current_tween], prev, next, .3);
+				break;
+			case 7:
+				tweens[current_tween] = Blend (tweens[current_tween], prev, next, .4);
+				break;
+			case 6:
+				tweens[current_tween] = Blend (tweens[current_tween], prev, next, .5);
+				break;
+			case 5:
+				tweens[current_tween] = Blend (tweens[current_tween], prev, next, .6);
+				break;
+			case 4:
+				tweens[current_tween] = Blend (tweens[current_tween], prev, next, .7);
+				break;
+			case 3:
+				tweens[current_tween] = Blend (tweens[current_tween], prev, next, .8);
+				break;
+			case 2:
+				tweens[current_tween] = Blend (tweens[current_tween], prev, next, .9);
+				break;
+			case 1:
+				tweens[current_tween] = Blend (tweens[current_tween], prev, next, .97);
+				break;
+			case 0:
+				tweens[current_tween] = Blend (tweens[current_tween], prev, next, .99);
+				break;
+			default:
+				tween_idle = 0;
+				return false;
+			}
+			
+			current_tween++;
+			return true;
 		}
 	}	
-
+	
 	private void StartTweenIdle () 
 	{
 		if (tween_idle == 0) {
